@@ -7,9 +7,6 @@ from cognite.airworkflow.util import env, repoconfighelpers
 working_path = env.get_env_value("PWD")
 ROOT_DIR = Path(working_path)
 FUNCTIONS_PATH = ROOT_DIR / "functions"
-CUSTOMERS_FUNCTIONS_PATH = FUNCTIONS_PATH / "customers"
-AIR_INFRA_FUNCTIONS_PATH = FUNCTIONS_PATH / "air_infrastructure"
-SHARED_FUNCTIONS_PATH = FUNCTIONS_PATH / "shared"
 IGNORE_MODELS_PATH = ROOT_DIR / ".ignore_models"
 
 # Paths within a functions folder
@@ -31,8 +28,6 @@ CONFIG_SCHEMA_PATH = SCHEMAS_PATH / "config-schema.yaml"
 
 url_dict = repoconfighelpers.get_url_dict()
 if Project.NAME.value in url_dict:
-    PROJECT_TO_API_KEYS = {
-        Project.NAME: ProjectInfo(Project.NAME, "AIR_DEPLOY_API_KEY", "AIR_API_KEY", str(url_dict[Project.NAME.value]))
-    }
+    PROJECT_TO_API_KEYS = {Project.NAME: ProjectInfo(Project.NAME, "AIR_API_KEY", str(url_dict[Project.NAME.value]))}
 else:
-    PROJECT_TO_API_KEYS = {Project.NAME: ProjectInfo(Project.NAME, "AIR_DEPLOY_API_KEY", "AIR_API_KEY")}
+    PROJECT_TO_API_KEYS = {Project.NAME: ProjectInfo(Project.NAME, "AIR_API_KEY")}
