@@ -26,7 +26,7 @@ class ModelAssetHierarchy:
         project_info = const.PROJECT_TO_API_KEYS[project]
         print("Project: " + project_info.name)
         self.client = CogniteClient(
-            api_key=project_info.get_deployment_key(),
+            api_key=project_info.get_client_api_key(),
             project=project_info.name,
             client_name="AIR Model Asset Client",
             base_url=project_info.base_url,
